==> django_fluo-0.2-py2.py3-none-any.whl: fluo/management/mixins.py <==
# -*- coding: utf-8 -*-

# Copyright (C) 2007-2016, Raffaele Salmaso <raffaele@salmaso.org>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

from __future__ import absolute_import, division, print_function, unicode_literals
import os


class ChdirMixin(object):
    def add_arguments(self, parser):
        super(ChdirMixin, self).add_arguments(parser)
        parser.add_argument('module', nargs='?', default=None, help='path/module to process')

    def handle(self, *args, **options):
        module = options.get('module')
        if module is not None:
            if os.path.exists(module):
                path = module
            else:
                from django.utils.importlib import import_module
                path = os.path.dirname(import_module(module).__file__)
            path = os.path.abspath(path)
            os.chdir(path)

        return super(ChdirMixin, self).handle(**options)

==> django_fluo-0.3.1-py2.py3-none-any.whl: fluo/management/mixins.py <==
# -*- coding: utf-8 -*-

# Copyright (C) 2007-2016, Raffaele Salmaso <raffaele@salmaso.org>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

from __future__ import absolute_import, division, print_function, unicode_literals
from importlib import import_module
import os


class ChdirMixin(object):
    def add_arguments(self, parser):
        super(ChdirMixin, self).add_arguments(parser)
        parser.add_argument('module', nargs='?', default=None, help='path/module to process')

    def handle(self, *args, **options):
        module = options.get('module')
        if module is not None:
            if os.path.exists(module):
                path = module
            else:
                path = os.path.dirname(import_module(module).__file__)
            path = os.path.abspath(path)
            os.chdir(path)

        return super(ChdirMixin, self).handle(**options)
